## Topsis Package
It takes an Datafile(.csv file) as an input along with 2 more arguments(weights ,impactas) along with name for output file(.csv format) as 4th argument

## Installation
```Syntax :```
```pip install Topsis-AbhayKansal-101903685```

## License

© 2022 Abhay Kansal

This repository is licensed under the MIT license. See LICENSE for details.touch